@@ -13,12 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core import urlresolvers
-from django.utils import http
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ungettext_lazy
+
 from horizon import tables
 
+from solumclient.v1 import app as cli_app
+
 from solumdashboard.api.client import client as solumclient
+from solumdashboard.applications import tabs
 
 
 class CreateApplication(tables.LinkAction):
@@ -28,43 +31,69 @@ class CreateApplication(tables.LinkAction):
     classes = ("btn-launch", "ajax-modal")
 
 
+class ScaleApplication(tables.LinkAction):
+    name = "scale"
+    verbose_name = _("Scale Application")
+    url = "horizon:solum:applications:scale"
+    classes = ("btn-launch", "ajax-modal")
+
+
+class UpdateApplication(tables.LinkAction):
+    name = "update"
+    verbose_name = _("Update Application")
+    url = "horizon:solum:applications:update"
+    classes = ("btn-launch", "ajax-modal")
+
+
 class LaunchApplication(tables.LinkAction):
     name = "build-and-deploy"
     verbose_name = _("Build and Deploy Application")
     url = "horizon:solum:applications:launch"
     classes = ("btn-launch", "ajax-modal")
 
-    def get_link_url(self, datum):
-        base_url = urlresolvers.reverse(self.url)
-
-        params = http.urlencode({"application_id": datum.id})
-        return "?".join([base_url, params])
+    def allowed(self, request, package):
+        return True
 
 
-class DeleteApplication(tables.BatchAction):
+class DeleteApplication(tables.DeleteAction):
     name = "delete"
-    verbose_name = _("Delete Application")
-    classes = ("btn-terminate", "btn-danger")
 
-    action_present = _("Delete")
-    action_past = _("Deleted")
-    data_type_singular = _("Application")
-    data_type_plural = _("Applications")
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Application",
+            u"Delete Applications",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Application",
+            u"Deleted Applications",
+            count
+        )
 
     def allowed(self, request, template):
         return True
 
-    def action(self, request, application_id):
+    def delete(self, request, application_id):
         solum = solumclient(request)
-        solum.plans.delete(plan_id=application_id)
+        cli_app.AppManager(solum).delete(app_id=application_id)
 
 
-class ViewApplication(tables.LinkAction):
+class ViewApplicationLogs(tables.LinkAction):
     name = "view"
-    verbose_name = _("View")
+    verbose_name = _("View Application Logs")
     url = "horizon:solum:applications:detail"
     classes = ("btn-edit",)
 
+    def get_link_url(self, datum):
+        base_url = super(ViewApplicationLogs, self).get_link_url(datum)
+        tab_query_string = tabs.LogTab(
+            tabs.AppDetailsTabs).get_query_string()
+        return "?".join([base_url, tab_query_string])
+
 
 class ApplicationsTable(tables.DataTable):
     name = tables.Column('name', verbose_name=_('Name'))
@@ -82,4 +111,5 @@ class ApplicationsTable(tables.DataTable):
         name = "applications"
         verbose_name = _("Applications")
         table_actions = (CreateApplication, DeleteApplication)
-        row_actions = (ViewApplication, LaunchApplication, DeleteApplication)
+        row_actions = (ViewApplicationLogs, LaunchApplication,
+                       DeleteApplication, ScaleApplication, UpdateApplication)
