@@ -29,7 +29,11 @@ urlpatterns = patterns(
     url(r'^$', views.IndexView.as_view(), name='index'),
     url(r'^$', views.IndexView.as_view(), name='applications'),
     url(r'^create$', views.CreateView.as_view(), name='create'),
-    url(r'^launch$', views.LaunchApplicationView.as_view(),
+    url(r'^launch/(?P<application_id>[^/]+)$', views.LaunchView.as_view(),
         name='launch'),
-    url(r'^(?P<application_id>[^/]+)$', views.DetailView.as_view(),
-        name='detail'))
+    url(r'^detail/(?P<application_id>[^/]+)$',
+        views.DetailView.as_view(), name='detail'),
+    url(r'^scale/(?P<application_id>[^/]+)$', views.ScaleView.as_view(),
+        name='scale'),
+    url(r'^update/(?P<application_id>[^/]+)$', views.UpdateView.as_view(),
+        name='update'))
